==> nextcloud-21.0.4.tgz: nextcloud/apps/dashboard/l10n/de_DE.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard-App",
    "Show something" : "Etwas anzeigen",
    "Customize" : "Anpassen",
    "Edit widgets" : "Widgets bearbeiten",
    "Get more widgets from the App Store" : "Holen Sie sich weitere Widgets aus dem App-Store",
    "Change background image" : "Hintergrundbild ändern",
    "Weather service" : "Wetterdienst",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Zu Ihrem Datenschutz werden die Wetterdaten von Ihrem Nextcloud-Server für Sie angefordert, so dass der Wetterdienst keine persönlichen Informationen erhält.",
    "Weather data from Met.no" : "Wetterdaten von Met.no",
    "geocoding with Nominatim" : "Geokodierung mit Nominatim",
    "elevation data from OpenTopoData" : "Höhendaten von OpenTopoData",
    "Weather" : "Wetter",
    "Status" : "Status",
    "Good morning" : "Guten Morgen",
    "Good morning, {name}" : "Guten Morgen {name}",
    "Good afternoon" : "Guten Tag",
    "Good afternoon, {name}" : "Guten Tag {name}",
    "Good evening" : "Guten Abend",
    "Good evening, {name}" : "Guten Abend {name}",
    "Hello" : "Hallo",
    "Hello, {name}" : "Hallo, {name}",
    "Pick from Files" : "Aus Dateien auswählen",
    "Default images" : "Standardbilder",
    "Plain background" : "Einfacher Hintergrund",
    "Insert from {productName}" : "Von {productName} einfügen",
    "Get more widgets from the app store" : "Holen Sie sich weitere Widgets aus dem App Store",
    "Good night, {name}" : "Gute Nacht {name}",
    "Good night" : "Gute Nacht",
    "Pick from files" : "Aus Dateien wählen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.2.10.tgz: nextcloud/apps/dashboard/l10n/de_DE.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard-App",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Starten Sie informiert in den Tag\n\nDas Nextcloud-Dashboard ist Ihr Ausgangspunkt für den Tag und gibt Ihnen\neinen Überblick über Ihre anstehenden Termine, dringende E-Mails, Chatnachrichten,\neingehende Tickets, neuste Tweets und vieles mehr! Benutzer können die Widgets hinzufügen\ndie sie mögen und der Hintergrund kann nach Ihren Wünschen angepasst.",
    "Customize" : "Anpassen",
    "Edit widgets" : "Widgets bearbeiten",
    "Get more widgets from the App Store" : "Holen Sie sich weitere Widgets aus dem App-Store",
    "Change background image" : "Hintergrundbild ändern",
    "Weather service" : "Wetterdienst",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Zu Ihrem Datenschutz werden die Wetterdaten von Ihrem Nextcloud-Server für Sie angefordert, so dass der Wetterdienst keine persönlichen Informationen erhält.",
    "Weather data from Met.no" : "Wetterdaten von Met.no",
    "geocoding with Nominatim" : "Geokodierung mit Nominatim",
    "elevation data from OpenTopoData" : "Höhendaten von OpenTopoData",
    "Weather" : "Wetter",
    "Status" : "Status",
    "Good morning" : "Guten Morgen",
    "Good morning, {name}" : "Guten Morgen {name}",
    "Good afternoon" : "Guten Tag",
    "Good afternoon, {name}" : "Guten Tag {name}",
    "Good evening" : "Guten Abend",
    "Good evening, {name}" : "Guten Abend {name}",
    "Hello" : "Hallo",
    "Hello, {name}" : "Hallo, {name}",
    "Pick from Files" : "Aus Dateien auswählen",
    "Default images" : "Standardbilder",
    "Plain background" : "Einfacher Hintergrund",
    "Insert from {productName}" : "Von {productName} einfügen",
    "Show something" : "Etwas anzeigen"
},
"nplurals=2; plural=(n != 1);");
